/**
 * @file
 * The commercetools_content ajax functionality.
 */

(() => {
  Drupal.behaviors.commercetoolsContentAjax = {
    attach(context) {
      const eventForms = [
        '.commercetools-content-catalog-facets-form',
        '.commercetools-content-product-search-form',
      ];

      const forms = once(
        'commercetoolsContentAjax',
        eventForms.join(', '),
        context,
      );
      forms.forEach((form) => {
        form.addEventListener('submit', (e) => {
          e.preventDefault();
          const formsData = this.getFormsData(eventForms);
          const params = new URLSearchParams(formsData);
          this.updateList(
            `${drupalSettings.path.currentPath}?${params.toString()}`,
          );
        });
      });

      // Making the Commercetools Product Catalog pager AJAX.
      const pagerLinks = once(
        'commercetoolsContentAjax',
        '#catalog-wr .pager a',
        context,
      );

      pagerLinks.forEach((link) => {
        link.addEventListener('click', (e) => {
          e.preventDefault();
          const query = link.getAttribute('href');
          this.updateList(`${drupalSettings.path.currentPath}${query}`);
        });
      });
    },

    // Get all forms data which related to catalog pages.
    getFormsData(formsSelector) {
      const forms = document.querySelectorAll(formsSelector.join(', '));
      const formsData = new FormData();
      const ignoreFields = ['form_build_id', 'form_token', 'form_id'];
      forms.forEach((form) => {
        const formData = new FormData(form);
        formData.forEach((v, k) => {
          if (v.trim() !== '' && !ignoreFields.includes(k)) {
            formsData.set(k, v);
          }
        });
      });

      return formsData;
    },

    // Request to update a list and update browser storage.
    updateList(url) {
      window.history.pushState({ path: url }, '', url);

      const ajaxSettings = {
        wrapper: 'catalog-wr',
        url: Drupal.url(`ajax/${url}`),
        progress: {
          type: 'fullscreen',
          message: Drupal.t('Processing...'),
        },
      };

      Drupal.ajax(ajaxSettings).execute();
    },
  };
})();
