class CartSummary extends HTMLElement {
  async connectedCallback() {
    this.total = 0;
    this.loading = true;
    this.maxItems = window.drupalSettings.commercetoolsDecoupled.maxItems;
    this.cartPath = window.drupalSettings.commercetoolsDecoupled.cartPath;
    // @todo Replace with the actual URL when the functionality is ready.
    this.checkoutPath = window.location.href;
    this.render();
    document.addEventListener(
      'commercetoolsDecoupledCartUpdated',
      this.handleCartUpdated.bind(this),
    );
    const cart = await window.commercetools.getCart();
    this.total = cart?.lineItems?.length || 0;
    this.loading = false;
    this.render();
  }

  handleCartUpdated(event) {
    this.total = event.detail.totalItems ?? '';
    this.render();
  }

  disconnectedCallback() {
    document.removeEventListener(
      'commercetoolsDecoupledCartUpdated',
      this.handleCartUpdated,
    );
  }

  render() {
    const cartBadge =
      this.total !== null && this.total > 0
        ? `<span class="position-absolute top-0 start-100 translate-middle badge rounded-pill bg-danger">${this.total}</span>`
        : '';

    const moreItemsLink =
      this.total > this.maxItems
        ? `<div class="text-center mt-2">
          <a href="${this.cartPath}" class="text-muted">
            ${this.total - this.maxItems} ${Drupal.t('more items')}
          </a>
        </div>`
        : '';

    const actionButtons =
      this.total > 0
        ? `<div class="row mt-4">
          <div class="col-6">
            <a href="${this.cartPath}" class="btn btn-outline-secondary w-100">
              ${Drupal.t('View Cart')}
            </a>
          </div>
          <div class="col-6">
            <a href="${this.checkoutPath}" class="btn btn-primary w-100">
              ${Drupal.t('Checkout')}
            </a>
          </div>
        </div>`
        : '';

    this.innerHTML = `
      <div class="commercetools-summary-block dropdown" ${this.loading ? 'style="cursor: progress"' : ''}>
        <button
          class="btn btn-light position-relative"
          type="button"
          id="cartDropdown"
          data-bs-toggle="dropdown"
          aria-expanded="false"
        >
          <i class="bi bi-bag fs-4"></i>
          ${cartBadge}
        </button>
        <div
          class="dropdown-menu dropdown-menu-end p-3 shadow-lg"
          aria-labelledby="cartDropdown"
          style="min-width: 680px; max-height: 400px; overflow-y: auto;"
        >
          <div class="cart-items">
            <ct-cart-info is-summary-cart="true"></ct-cart-info>
          </div>
          ${moreItemsLink}
          ${actionButtons}
        </div>
      </div>
    `;
  }
}

customElements.define('ct-cart-summary', CartSummary);
