class Pager extends HTMLElement {
  constructor() {
    super();
    this.currentPage = 0;
    this.totalPages = 1;
    this.handlePageClick = this.handlePageClick.bind(this);
  }

  connectedCallback() {
    this.renderPager();
    this.addEventListener('click', this.handlePageClick);
  }

  disconnectedCallback() {
    this.removeEventListener('click', this.handlePageClick);
  }

  handlePageClick(event) {
    event.preventDefault();
    const { target } = event;
    if (target.classList.contains('page-link')) {
      const page = parseInt(target.getAttribute('data-page'), 10);
      if (!Number.isNaN(page) && page >= 0 && page < this.totalPages) {
        this.dispatchEvent(
          new CustomEvent('page-change', { detail: { page } }),
        );
      }
    }
  }

  renderPager() {
    const fragment = document.createDocumentFragment();

    const nav = document.createElement('nav');
    nav.setAttribute('aria-label', 'product-pagination');

    const ul = document.createElement('ul');
    ul.className = 'pagination';

    ul.appendChild(Pager.createPageItem(0, '&laquo;', this.currentPage === 0));
    ul.appendChild(
      Pager.createPageItem(
        this.currentPage - 1,
        '&lsaquo;',
        this.currentPage === 0,
      ),
    );

    for (let i = 0; i < this.totalPages; i++) {
      ul.appendChild(
        Pager.createPageItem(
          i,
          (i + 1).toString(),
          false,
          i === this.currentPage,
        ),
      );
    }

    ul.appendChild(
      Pager.createPageItem(
        this.currentPage + 1,
        '&rsaquo;',
        this.currentPage === this.totalPages - 1,
      ),
    );
    ul.appendChild(
      Pager.createPageItem(
        this.totalPages - 1,
        '&raquo;',
        this.currentPage === this.totalPages - 1,
      ),
    );

    nav.appendChild(ul);
    fragment.appendChild(nav);
    this.innerHTML = '';
    this.appendChild(fragment);
  }

  static createPageItem(page, label, isDisabled = false, isActive = false) {
    const li = document.createElement('li');
    // @todo Rework it to the better approach.
    let bemClasses;
    switch (label) {
      case '&laquo;':
        bemClasses = 'page-item page-item--first';
        break;
      case '&lsaquo;':
        bemClasses = 'page-item page-item--prev';
        break;
      case '&rsaquo;':
        bemClasses = 'page-item page-item--next';
        break;
      case '&raquo;':
        bemClasses = 'page-item page-item--last';
        break;
      default:
        bemClasses = 'page-item';
    }
    li.className = `${bemClasses} page-item${isDisabled ? ' disabled' : ''}${isActive ? ' active' : ''}`;

    const inner = isActive
      ? document.createElement('span')
      : document.createElement('a');
    inner.className = 'page-link';
    const url = new URL(window.location);
    url.searchParams.set('page', page);
    inner.href = isDisabled ? '#' : url.toString();
    inner.setAttribute('data-page', page);
    inner.innerHTML = label;

    li.appendChild(inner);
    return li;
  }

  setPager(currentPage, totalPages) {
    this.currentPage = currentPage;
    this.totalPages = totalPages;
    this.renderPager();
  }
}

customElements.define('ct-pager', Pager);
