class ProductCard extends HTMLElement {
  connectedCallback() {
    const placeholderProduct = {
      name: 'Placeholder for title',
      slug: 'placeholder-path',
      masterVariant: {
        images: [{ url: '' }],
        price: { localizedPrice: '$1000' },
      },
      isLoading: true,
    };
    const product = this.isLoading !== true ? this.product : placeholderProduct;
    this.name = product.name;
    if (!product.slug) {
      new Drupal.Message().add(
        'The product slug value is missing for a product.',
        { type: 'error' },
      );
    }
    this.path = Drupal.url(
      `${drupalSettings.commercetoolsDecoupled.catalogPath.substring(1)}/${product.slug}`,
    );
    this.image = product.masterVariant.images[0]?.url;
    this.price = product.masterVariant.price.localizedPrice;
    this.isLoading = product.isLoading;

    this.innerHTML = /* html */ `

    <figure class="card${this.isLoading ? ' placeholderify' : ''}">
      <a href="${this.path}">
        <div class="card-img-wrapper" style="${
          this.isLoading ? 'aspect-ratio: 304/405; ' : ''
        }overflow: hidden;">
          <img src="${this.image}" alt="${
            this.name
          }" class="card-img card-img-top" style="height: 100%; object-fit: cover;" />
        </div>
      </a>
      <div class="card-body">
        <h2 class="card-title fs-5 text-truncate text-primary"><a class="text-decoration-none" href="${
          this.path
        }">${this.name}</a></h2>
      </div>
      <div class="card-footer bg-transparent">
        <a href="${this.path}" class="card-btn btn btn-primary btn-sm float-end">${Drupal.t('Details')}</a>
        <span class="price">${this.price}</span>
      </div>
    </figure>
    `;
  }
}

customElements.define('ct-product-card', ProductCard);
