class FacetsForm extends HTMLElement {
  connectedCallback() {
    const form = document.createElement('form');
    form.classList.add('facets-form');
    form.innerHTML = '<h2 class="pb-3 border-bottom">Filters</h2>';

    if (this.facetChangeHandle) {
      form.addEventListener('change', this.facetChangeHandle);
    }

    try {
      this.renderFacets(form);
    } catch (error) {
      new Drupal.Message().add(Drupal.t('Failed to load filters.'), {
        type: 'error',
      });
      throw error;
    }
    this.appendChild(form);
  }

  renderFacets(form) {
    if (this.isLoading) {
      form.insertAdjacentHTML('beforeend', FacetsForm.placeholder());
      return;
    }

    this.facets.forEach((facetObj) => {
      if (!facetObj || !facetObj.value) {
        new Drupal.Message().add(Drupal.t('Invalid filter data.'), {
          type: 'warning',
        });
        return;
      }

      // Hide the empty facet.
      if (!facetObj.value.terms.length) {
        return;
      }

      const fieldset = document.createElement('fieldset');
      fieldset.classList.add(
        'fieldgroup',
        'form-composite',
        'form-item',
        'form-wrapper',
      );
      const legend = document.createElement('legend');
      legend.innerHTML = `<span class="fieldset-legend">${facetObj.label}</span>`;
      fieldset.appendChild(legend);

      facetObj.value.terms.forEach((termObj) => {
        const { term, productCount } = termObj;
        const id = `${facetObj.facet}-${term}`.replace(/\W/g, '-');

        const checkbox = document.createElement('input');
        checkbox.type = 'checkbox';
        checkbox.name = `facets[${facetObj.facet}][${term}]`;
        checkbox.value = term;
        checkbox.checked = this.activeFilters[facetObj.facet]?.includes(term);
        checkbox.setAttribute('id', id);

        const label = document.createElement('label');
        label.htmlFor = id;
        label.classList.add('option');
        label.innerHTML = `<span class="ms-3 text-truncate">${term}</span><span class="float-end">(${productCount})</span>`;

        fieldset.appendChild(checkbox);
        fieldset.appendChild(label);

        fieldset.appendChild(document.createElement('br'));
      });

      form.appendChild(fieldset);
    });
  }

  static placeholder() {
    return `
      <fieldset class="fieldgroup form-composite js-form-item form-item js-form-wrapper form-wrapper placeholderify">
        <legend><span class="fieldset-legend">Placeholder for the facet name</span></legend>
        <div class="fieldset-wrapper">
          ${Array.from({ length: 6 }, () => {
            return `
              <input type="checkbox" name="name" value="value" class="form-checkbox form-check-input">
              <label for="edit-name" class="option"><span class="ms-3 text-truncate">Facet checkbox</span> <span class="float-end">(10)</span></label>
              <hr />
            `;
          }).join('')}
        </div>
      </fieldset>
    `;
  }
}

customElements.define('ct-facets-form', FacetsForm);
