<?php

namespace Drupal\commercetools_decoupled;

use Drupal\commercetools\CommercetoolsApiServiceInterface;
use Drupal\commercetools\CommercetoolsLocalization;
use Drupal\commercetools\CommercetoolsService;
use Drupal\commercetools\Form\UiModuleSettingsFormBase;
use Drupal\commercetools\Routing\UiModulesRouteProviderBase;
use Drupal\commercetools_decoupled\Form\DecoupledSettingsForm;
use Drupal\commercetools_decoupled\Routing\RouteProvider;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;

/**
 * Commercetools Decoupled main service.
 */
class CommercetoolsDecoupled {

  /**
   * CommercetoolsApiService constructor.
   *
   * @param \Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory service.
   * @param \Drupal\commercetools\CommercetoolsService $ct
   *   The Commercetools service.
   * @param \Drupal\commercetools\CommercetoolsApiServiceInterface $ctApi
   *   The Commercetools API service.
   * @param \Drupal\commercetools\CommercetoolsLocalization $ctLocalization
   *   The commercetools localization service.
   */
  public function __construct(
    protected readonly AccountInterface $currentUser,
    protected readonly ConfigFactoryInterface $configFactory,
    protected readonly CommercetoolsService $ct,
    protected readonly CommercetoolsApiServiceInterface $ctApi,
    protected readonly CommercetoolsLocalization $ctLocalization,
  ) {

  }

  /**
   * Returns an array with common settings required for frontend components.
   *
   * @return array[]
   *   An array with Drupal decoupled settings.
   */
  public function getDrupalSettings(): array {
    $generalSettings = $this->configFactory->get(CommercetoolsService::CONFIGURATION_NAME);
    $connectionSettings = $this->configFactory->get(CommercetoolsApiServiceInterface::CONFIGURATION_NAME);
    $decoupledSettings = $this->configFactory->get(DecoupledSettingsForm::CONFIGURATION_NAME);
    $localizationSettings = $this->configFactory->get(CommercetoolsLocalization::CONFIGURATION_NAME);

    return [
      'commercetoolsDecoupled' => [
        'catalogPath' => $decoupledSettings->get(UiModuleSettingsFormBase::CONFIG_CATALOG_PATH),
        'cartPath' => $decoupledSettings->get(UiModuleSettingsFormBase::CONFIG_CART_PATH),
        'checkoutPath' => $decoupledSettings->get(UiModuleSettingsFormBase::CONFIG_CHECKOUT_PATH),
        'orderPathPrefix' => Url::fromRoute(RouteProvider::ROUTE_PREFIX . UiModulesRouteProviderBase::PAGE_USER_ORDERS_ROUTE, ['user' => $this->currentUser->id()])->toString(),
        'apiUrl' => $decoupledSettings->get(DecoupledSettingsForm::CONFIG_API_PROXY_PATH) ?: CommercetoolsApiServiceInterface::API_PROXY_PATH_DEFAULT,
        'projectKey' => $connectionSettings->get(CommercetoolsApiServiceInterface::CONFIG_PROJECT_KEY),
        'locale' => $localizationSettings->get(CommercetoolsLocalization::CONFIG_LANGUAGE),
        'languages' => $this->ctLocalization->getLanguageFallbacks(),
        'priceCountry' => $localizationSettings->get(CommercetoolsLocalization::CONFIG_COUNTRY),
        'priceCurrency' => $localizationSettings->get(CommercetoolsLocalization::CONFIG_CURRENCY),
        'priceGroup' => $generalSettings->get(CommercetoolsService::CONFIG_PRICE_CUSTOMER_GROUP),
        'priceChannel' => $localizationSettings->get(CommercetoolsLocalization::CONFIG_CHANNEL),
        'facets' => $this->ct->getEnabledFacets(),
        'attributes' => $this->ct->getEnabledAttributes(),
        'itemsPerPage' => $generalSettings->get(CommercetoolsService::CONFIG_ITEMS_PER_PAGE),
        'unavailableDataText' => $generalSettings->get(CommercetoolsService::CONFIG_UNAVAILABLE_DATA_TEXT),
        'apiRegion' => $this->ctApi->getApiUrl('region'),
        'resetUri' => Url::fromRoute(RouteProvider::ROUTE_PREFIX . UiModulesRouteProviderBase::PAGE_RESET_CART_ROUTE)->toString(),
      ],
    ];
  }

}
