<?php

namespace Drupal\commercetools_decoupled\Plugin\Block;

use Drupal\commercetools_decoupled\Form\DecoupledSettingsForm;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the Commercetools Decoupled Cart Summary block.
 *
 * @Block(
 *   id = "commercetools_decoupled_cart_summary",
 *   admin_label = @Translation("Decoupled Cart Summary"),
 * )
 */
class CommercetoolsDecoupledCartSummaryBlock extends BlockBase {

  /**
   * Default number of items to display.
   */
  protected const MAX_ITEMS_DEFAULT = 5;

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['max_items'] = [
      '#type' => 'number',
      '#title' => $this->t('Number of items to display'),
      '#description' => $this->t('The number of items to display in the cart summary.'),
      '#default_value' => $config['max_items'] ?? self::MAX_ITEMS_DEFAULT,
      '#min' => 1,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $this->setConfigurationValue('max_items', $form_state->getValue('max_items'));
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    $max_items = $config['max_items'] ?? self::MAX_ITEMS_DEFAULT;
    return [
      '#type' => 'component',
      '#component' => 'commercetools_decoupled:cart-block',
      '#attached' => [
        'drupalSettings' => [
          'commercetoolsDecoupled' => [
            'maxItems' => (int) $max_items,
          ],
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags(): array {
    $cacheTags = parent::getCacheTags();
    return Cache::mergeTags($cacheTags, [
      'config:' . DecoupledSettingsForm::CONFIGURATION_NAME,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    $cacheContexts = parent::getCacheContexts();
    return Cache::mergeContexts($cacheContexts, [
      'commercetools_cart',
    ]);
  }

}
