<?php

declare(strict_types=1);

namespace Drupal\commercetools_decoupled\Plugin\Block;

use Drupal\commercetools\Plugin\Block\CommercetoolsProductListBlockBase;
use Drupal\commercetools_decoupled\CommercetoolsDecoupled;
use Drupal\commercetools_decoupled\Form\DecoupledSettingsForm;
use Drupal\Core\Cache\Cache;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a product list block.
 *
 * @Block(
 *   id = "commercetools_decoupled_product_list",
 *   admin_label = @Translation("Decoupled Product List"),
 * )
 */
class CommercetoolsDecoupledProductListBlock extends CommercetoolsProductListBlockBase {

  /**
   * Commercetools Decoupled main service.
   *
   * @var \Drupal\commercetools_decoupled\CommercetoolsDecoupled
   */
  protected CommercetoolsDecoupled $ctDecoupled;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->ctDecoupled = $container->get('commercetools_decoupled');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    return [
      '#type' => 'component',
      '#component' => 'commercetools_decoupled:products-list',
      '#props' => $config,
      '#attached' => [
        'drupalSettings' => $this->ctDecoupled->getDrupalSettings(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags(): array {
    $cacheTags = parent::getCacheTags();
    return Cache::mergeTags($cacheTags, [
      'config:' . DecoupledSettingsForm::CONFIGURATION_NAME,
    ]);
  }

}
