<?php

declare(strict_types=1);

namespace Drupal\commercetools_test;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Lock\LockBackendInterface;
use Drupal\Core\State\StateInterface;
use Drupal\test_helpers_http_client_mock\HttpClientFactoryMock;
use GraphQL\Language\Parser;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Response;

/**
 * Overridden version of the HttpClientFactoryMock.
 */
class CommercetoolsHttpClientFactoryMock extends HttpClientFactoryMock {

  /**
   * {@inheritdoc}
   */
  public function __construct(
    HandlerStack $stack,
    protected StateInterface $state,
    protected ConfigFactoryInterface $configFactory,
    protected LockBackendInterface $lock,
    protected ?string $requestMockMode = NULL,
    protected ?string $responsesStorageDirectory = NULL,
    protected ?string $testName = NULL,
    protected ?string $uriRegexp = NULL,
  ) {
    parent::__construct(
      $stack,
      $state,
      $configFactory,
      $lock,
      $requestMockMode,
      $responsesStorageDirectory,
      $testName,
    );

    $commercetoolsRequestsHandler = function (callable $handler) {
      return function ($request, array $options) use ($handler) {
        $data = json_decode($request->getBody()->getContents(), TRUE);
        $graphQlQueryOperation = $this->getGraphQlOperation($data['query']);

        // Emulating empty commercetools messages to handle cron runs.
        if ($graphQlQueryOperation == 'messages') {
          $response = [
            'data' => [
              'messages' => [
                'total' => 0,
                'results' => [],
              ],
            ],
          ];
          return new Response(200, [], json_encode($response));
        }
        return $handler($request, $options);
      };
    };

    $this->stubSetCustomHandler($commercetoolsRequestsHandler);
  }

  /**
   * Extracts the operation name from a GraphQL query as string.
   *
   * @param string $query
   *   A GraphQL query as string.
   * @param int $delta
   *   The operation delta, 0 by default.
   *
   * @return string
   *   The operation name.
   */
  protected function getGraphQlOperation(string $query, int $delta = 0): string {
    $queryObject = Parser::parse($query);
    $queryRootNodes = $queryObject->toArray()['definitions'];
    $node = $queryRootNodes->offsetGet($delta);
    $operation = $node->selectionSet->selections->offsetGet(0)->name->value;
    return $operation;
  }

  /**
   * Extends the parent to format the stored requests for commercetools testing.
   *
   * {@inheritdoc}
   */
  protected function stubGetRequestMetadata($request): array {
    $metadata = parent::stubGetRequestMetadata($request);
    $metadata = CommerceToolsTesting::formatCtRequestAssetMetadata($metadata);
    return $metadata;
  }

}
