const { cart, page, product } = require('./selectors');
const commerceToolsConfigs = require('./commerceToolsConfigs');
const addCatalogProductToCart = require('./utils/addCatalogProductToCart');

module.exports = function checkAnonymousCart(browser, module) {
  const moduleConfig = commerceToolsConfigs[module][`${module}.settings`];
  const cartPath = moduleConfig.cart_path;
  const catalogPath = moduleConfig.catalog_path;

  // Create testing customer.
  const mail = 'commercetools-test-user@example.com';
  const name = 'commercetools-test-user';
  browser.perform(async () => {
    await browser.thCreateUser({ mail, name });
  });

  // @todo Make a dynamic check for the card in stock.
  const cardInStockIndex = 4;

  // Ensure that anonymous cart is empty.
  browser
    .perform(async () => {
      await browser
        .drupalRelativeURL(cartPath)
        .waitForElementVisible(cart.component)
        .expect.element(cart.emptyText).to.be.present;
    })

    // Add some product to anonymous cart.
    .perform(async () => {
      await browser
        .drupalRelativeURL(catalogPath)
        .waitForElementVisible(product.catalog);

      await addCatalogProductToCart(browser, cardInStockIndex);

      await browser
        .waitForElementVisible(page.messages)
        .testHelpersHttpMockSetSettings({ context: 'Cart with products' })
        .drupalRelativeURL(cartPath)
        .waitForElementVisible(cart.lineItems)
        .expect.element(cart.lineItems).to.be.present;
    })

    .perform(async () => {
      // Delete all cookies created after adding an item to the cart.
      const cookies = await browser.cookies.getAll();
      cookies.forEach((cookie) => {
        if (cookie.name !== 'SIMPLETEST_USER_AGENT') {
          browser.cookies.delete(cookie.name);
        }
      });

      // The cart page should be empty when there are no cookies.
      await browser
        .testHelpersHttpMockSetSettings({ context: 'Remove session cookies' })
        .drupalRelativeURL(cartPath)
        .waitForElementVisible(cart.component)
        .expect.element(cart.emptyText).to.be.present;

      // Return all cookies back after checking.
      cookies.forEach((cookie) => {
        if (cookie.name !== 'SIMPLETEST_USER_AGENT') {
          browser.cookies.set(cookie);
        }
      });
    })
    // Log in as a registered customer to ensure cart is replaced.
    .perform(async () => {
      await browser
        .thLogin(name)
        .testHelpersHttpMockSetSettings({ context: 'Cart of a logged user' })
        .drupalRelativeURL(cartPath)
        .waitForElementVisible(cart.component)
        .expect.element(cart.emptyText).to.be.present;
    });
};
