const {
  product: { page },
} = require('./selectors');
const getSomeProduct = require('./getSomeProduct');
const getResponseFromLatestByDataType = require('./getResponseFromLatestByDataType');
const setMockMode = require('./setMockMode');
const unsetMockMode = require('./unsetMockMode');
const commerceToolsConfigs = require('./commerceToolsConfigs');

module.exports = async function checkProductPageCaching(browser, module) {
  const urlPrefix =
    commerceToolsConfigs[module][`${module}.settings`].catalog_path;
  const titleMocked = 'Product Title Mocked';
  const dataType = 'products';

  let product;
  let titleFromApi;
  let url;

  await getSomeProduct(browser, urlPrefix, (result) => {
    product = result.value;
    titleFromApi = product.name;
    url = `${urlPrefix}/${product.slug}`;
  });

  browser.perform(async () => {
    // Check original content before mocking
    browser
      .drupalRelativeURL(url)
      .waitForElementVisible(page.component)
      .assert.textEquals(page.title, titleFromApi);

    // Modifying the mocked response
    const storedResponse = await getResponseFromLatestByDataType(
      browser,
      dataType,
    );
    const mockedResponseData = JSON.parse(JSON.stringify(storedResponse.value));
    mockedResponseData.data.products.results[0].masterData.current.name =
      titleMocked;

    await browser.thSetRequestResponseByHash(
      storedResponse.hash,
      JSON.stringify(mockedResponseData),
    );

    // Activate Mock Mode
    setMockMode(browser);

    // Check if the mocked content is displayed after cache clear
    await browser
      .drupalRelativeURL(url)
      .waitForElementVisible(page.component)
      .assert.textEquals(page.title, titleFromApi)

      // Checking if the GraphQL response is properly cached.
      .drupalRelativeURL(`${url}?foo=bar`)
      .waitForElementVisible(page.component)
      .assert.textEquals(page.title, titleFromApi)

      // Simulate the Commercetools message to invalidate the current product.
      .thDrupalFetchURL(
        `/commercetools-test/message-invalidate-product/${product.id}`,
      )
      .drupalRelativeURL(url)
      .waitForElementVisible(page.component)
      .assert.textEquals(page.title, titleMocked)
      .thSetRequestResponseByHash(
        storedResponse.hash,
        JSON.stringify(storedResponse.value),
      );
    unsetMockMode(browser);
  });
};
