const {
  product: { catalog, card, page },
  page: { messages },
  cart,
  bootstrap: { pager },
} = require('./selectors');
const checkSearchForm = require('./checkSearchForm');
const checkCartSummaryBlock = require('./checkCartSummaryBlock');
const checkProductList = require('./checkProductList');
const getResponseFromLatestByDataType = require('./getResponseFromLatestByDataType');
const clickAndWaitForReRender = require('./utils/clickAndWaitForReRender');

module.exports = function shopSmokeTest(browser, catalogUrl) {
  const currencyCountryPairs = [
    { currency: 'USD', country: 'US' },
    { currency: 'EUR', country: 'DE' },
  ];
  for (let i = 0; i < currencyCountryPairs.length; i++) {
    const settings = currencyCountryPairs[i];

    // A variable to store the product title.
    let productTitle;

    // The card index number to click on.
    // For now, just hardcoding the card number 4 that is in stock in our data.
    // @todo Make a dynamic check for the card in stock, when the stock info
    // will be available on the card.
    const cardInStockIndex = 4;

    browser
      .thSetConfig('commercetools.locale', settings)
      // Open the main product catalog page.
      .drupalRelativeURL(catalogUrl)
      .waitForElementVisible(catalog)
      .waitForElementVisible(card.component)
      .perform(async () => {
        const apiResponse = await getResponseFromLatestByDataType(
          browser,
          'productProjectionSearch',
        );
        const productListItems =
          apiResponse.value.data.productProjectionSearch.results;
        // @todo Remove the condition after the decoupled version is implemented.
        if (module === 'commercetools_content') {
          await checkSearchForm(browser, productListItems, settings);
        }
        await checkProductList(browser, productListItems, settings);
        productTitle = await browser.getText(
          browser
            .element({ selector: card.component, index: cardInStockIndex })
            .findElement(card.title),
        );
        await checkCartSummaryBlock(
          browser,
          productListItems,
          catalogUrl,
          settings,
        );
        await browser.drupalRelativeURL(catalogUrl);
      })

      // Jump to the second page in the pager and wait for the component to refresh.
      .perform(async () => {
        await clickAndWaitForReRender(
          browser,
          // Using index as 0, because the first pager item is not a link.
          { selector: pager.item, index: 0 },
          pager.component,
          { selector: card.component, index: cardInStockIndex },
        );
      })

      // Check that the product title is changed.
      .perform(async () => {
        const productTitleCurrent = await browser.getText(
          browser
            .element({ selector: card.component, index: cardInStockIndex })
            .findElement(card.title),
        );
        browser.assert.notEqual(
          productTitleCurrent,
          productTitle,
          'The product title has not changed after jumping to the page 2 by the pager.',
        );
      })

      // Jump back to the first page in the pager and wait for the component to refresh.
      .perform(async () => {
        await clickAndWaitForReRender(
          browser,
          { selector: pager.item, index: 0 },
          pager.component,
          { selector: card.component, index: cardInStockIndex },
        );
      })

      // Get the product title to check on next pages.
      .perform(async () => {
        const productTitleCurrent = await browser.getText(
          browser
            .element({ selector: card.component, index: cardInStockIndex })
            .findElement(card.title),
        );
        browser.assert.equal(
          productTitleCurrent,
          productTitle,
          'The product title should be the same after jumping to the page 1 by the pager.',
        );
      })

      // Click on the product card.
      .click(
        browser
          .element({ selector: card.component, index: cardInStockIndex })
          .findElement(card.title),
      )
      .waitForElementVisible(page.component)
      .perform(() => {
        // @todo Add selector for the specific cart line item.
        browser.expect.element(page.title).text.to.contain(productTitle);
      });

    // Cart is implemented only in the coupled module.
    // @todo Remove the condition after the decoupled version is implemented.
    if (module === 'commercetools_content') {
      browser
        .click(browser.element(page.component).findElement(page.addToCart))

        // Click on the message link.
        .waitForElementVisible(page.component)
        .waitForElementVisible(messages)
        .click(browser.element(messages).findElement('a'))

        // Check the cart contents.
        .waitForElementVisible(cart.lineItems)
        .perform(() => {
          // @todo Add selector for the specific cart line item.
          browser.expect.element(cart.lineItems).text.to.contain(productTitle);
        });
    }
  }
};
