// eslint-disable-next-line import/no-extraneous-dependencies
const webdriver = require('selenium-webdriver');

/**
 * Click on an element and wait for it to disappear from the page.
 *
 * Useful to check the action elements on the frontend, which rerender the
 * component without reloading the page.
 *
 * @param {object} browser
 *   Nightwatch browser instance.
 * @param {object} clickElementSelector
 *   The selector to click on.
 * @param {object} clickElementParentElement
 *   The parent element of the selector.
 * @param {object} checkElementSelector
 *   The selector to check for disappear and appear.
 */
module.exports = async function clickAndWaitForReRender(
  browser,
  clickElementSelector,
  clickElementParentElement,
  checkElementSelector,
) {
  let clickElement;
  if (clickElementParentElement) {
    clickElement = await browser
      .element(clickElementParentElement)
      .findElement(clickElementSelector);
  } else {
    clickElement = await browser.findElement(clickElementSelector);
  }

  if (!checkElementSelector) {
    checkElementSelector = clickElementSelector;
  }
  const checkElement = await browser.findElement(checkElementSelector);
  const elId = checkElement.getId();
  await browser.click(clickElement);

  // The `webdriver.By.id(id)` started to put the CSS selector into the `value`
  // property in the latest version of the `selenium-webdriver` package.
  // But Nightwatch expects it in the `selector` property.
  const elIdSelectorObject = webdriver.By.id(elId);
  // Wait for the checking element to disappear.
  await browser.waitForElementNotPresent(elIdSelectorObject.value);

  // A workaround for a Selenium issue with an error:
  // "stale element reference: stale element not found in the current frame"
  // and another issue when the function `findElement` finds the same element
  // with the same id, by which she was convinced that it does not exist
  // using the function waitForElementNotPresent() call.
  // @todo Find a better solution.
  /* eslint-disable no-await-in-loop */
  let elReloadedId;
  for (let i = 0; i < 10; i++) {
    if (await browser.waitForElementVisible(checkElementSelector)) {
      const checkElementReloaded =
        await browser.findElement(checkElementSelector);
      elReloadedId = checkElementReloaded.getId();
      if (elId !== elReloadedId) {
        break;
      }
    }
    await browser.pause(100);
  }
  if (elId === elReloadedId) {
    throw new Error('The element was not rerendered.');
  }
};
